import { JSXElement, createEffect, createSignal } from "solid-js";

import { PublicComment } from "../Util/api";

export function Comment(props: { comment: PublicComment }): JSXElement {
  const [creationDate, setCreationDate] = createSignal<string>("");
  const [content, setContent] = createSignal<string>("");

  createEffect(() => {
    const date = new Date(props.comment.created_at);
    if (!isNaN(date.getTime())) {
      setCreationDate(date.toDateString());
    } else {
      // Set creation date to an empty string or any default value when the date is invalid
      setCreationDate("");
    }
    setContent(props.comment.content);
  });

  return (
    <>
      {creationDate() && ( // Render creation date only if it's not an empty string
        <div class="py-5">
          <time class="text-xs opacity-50">{creationDate()}</time>
        </div>
      )}
      <div class="text-base">{content()}</div>
      <div class="divider" />
    </>
  );
}
